from django.db import models
from django.contrib.auth.models import User
from django.core.exceptions import ObjectDoesNotExist
from django.utils import timezone
from django.utils.translation import ugettext as _
from ohm2_handlers_light.models import BaseModel
from . import managers
from . import settings



class Staff(BaseModel):
	user = models.OneToOneField(User, on_delete = models.CASCADE)

	class Meta:
		permissions = settings.STAFF_PERMISSIONS